A constructor for pandoc list attributes.
ListAttributes(
first_number = 1L,
style = "DefaultStyle",
delim = "DefaultDelim"
)an integer giving the first number of the list
a character string giving the style, possible values are "DefaultStyle",
"Example", "Decimal", "LowerRoman",
"UpperRoman", "LowerAlpha" and "UpperAlpha".
a character string giving the delimiter, possible values are "DefaultDelim",
"Period", "OneParen" and "TwoParens".